@@ -1,13 +1,17 @@
 package Dist::Zilla::Plugin::NoTabsTests;
 # ABSTRACT: (DEPRECATED) Release tests making sure hard tabs aren't used
-$Dist::Zilla::Plugin::NoTabsTests::VERSION = '0.13';
+
+our $VERSION = '0.14';
+
 use Moose;
 extends 'Dist::Zilla::Plugin::Test::NoTabs';
 
 use namespace::autoclean;
 
 before register_component => sub {
-    warn "!!! [NoTabsTests] is deprecated and may be removed in a future release; replace it with [Test::NoTabs]\n";
+    warnings::warnif('deprecated',
+        "!!! [MungeFile::WithData] is deprecated and will be removed in a future release; replace it with [MungeFile::WithDataSection]\n",
+    );
 };
 
 has '+filename' => (
@@ -28,7 +32,7 @@ Dist::Zilla::Plugin::NoTabsTests - (DEPRECATED) Release tests making sure hard t
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
