@@ -1,14 +1,16 @@
-package Dist::Zilla::Plugin::Test::NoTabs; # git description: v0.12-1-gdb8469b
+package Dist::Zilla::Plugin::Test::NoTabs; # git description: v0.13-19-gbebd27c
 # ABSTRACT: Author tests that ensure hard tabs are not used
 # KEYWORDS: plugin test testing author development whitespace tab tabstop indent formatting
-# vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::Plugin::Test::NoTabs::VERSION = '0.13';
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+
+our $VERSION = '0.14';
+
 use Moose;
 use Path::Tiny;
 use Sub::Exporter::ForMethods 'method_installer'; # method_installer returns a sub.
 use Data::Section 0.004 # fixed header_re
     { installer => method_installer }, '-setup';
-use Moose::Util::TypeConstraints;
+use Moose::Util::TypeConstraints 'role_type';
 use namespace::autoclean;
 
 with
@@ -91,8 +93,8 @@ sub register_prereqs
             type  => 'requires',
             phase => 'develop',
         },
-        'Test::More' => 0,
-        'Test::NoTabs' => 0,
+        'Test::More' => '0.88',
+        'Test::NoTabs' => '0',
     );
 }
 
@@ -138,6 +140,7 @@ sub munge_files
 
     return;
 }
+
 __PACKAGE__->meta->make_immutable;
 
 #pod =pod
@@ -188,6 +191,12 @@ __PACKAGE__->meta->make_immutable;
 #pod
 #pod The filename of the test to add - defaults to F<xt/author/no-tabs.t>.
 #pod
+#pod =head1 SEE ALSO
+#pod
+#pod =for :list
+#pod * Test::NoTabs
+#pod * Test::Tabs
+#pod
 #pod =cut
 
 =pod
@@ -200,7 +209,7 @@ Dist::Zilla::Plugin::Test::NoTabs - Author tests that ensure hard tabs are not u
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -247,6 +256,20 @@ earlier. This option can be repeated to specify multiple additional files.
 
 The filename of the test to add - defaults to F<xt/author/no-tabs.t>.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item *
+
+Test::NoTabs
+
+=item *
+
+Test::Tabs
+
+=back
+
 =head1 AUTHOR
 
 Florian Ragwitz <rafl@debian.org>
@@ -271,7 +294,7 @@ ___[ __TEST__ ]___
 use strict;
 use warnings;
 
-# this test was generated with {{ ref($plugin) . ' ' . ($plugin->VERSION || '<self>') }}
+# this test was generated with {{ ref($plugin) . ' ' . $plugin->VERSION }}
 
 use Test::More 0.88;
 use Test::NoTabs;
